<?php
/**
 * Plugin Name: Mimoza AI SEO İçerik Eklentisi
 * Plugin URI: https://mimozabilisim.com/wordpress-seo-eklentileri/
 * Description: ChatGPT & Claude AI (Anthropic API) ile SEO uyumlu içerik üreten WordPress eklentisi. Yoast & Rank Math SEO entegrasyonu içerir.
 * Version: 2.6
 * Author: Mimoza Bilişim
 * Author URI: https://mimozabilisim.com/hakkimizda/
 */

if (!defined('ABSPATH')) exit;

// Admin menüsünü ekleyelim
function seo_ai_content_menu() {
    add_menu_page('Mimoza AI SEO İçerik', 'Mimoza AI SEO İçerik', 'manage_options', 'seo-ai-content', 'seo_ai_content_page', 'dashicons-admin-generic', 6);
    add_submenu_page('seo-ai-content', 'Ayarlar', 'Ayarlar', 'manage_options', 'seo-ai-settings', 'seo_ai_settings_page');
}
add_action('admin_menu', 'seo_ai_content_menu');

// Ayarları kaydetme
function seo_ai_register_settings() {
    register_setting('seo_ai_options_group', 'seo_ai_openai_api_key');
    register_setting('seo_ai_options_group', 'seo_ai_claude_api_key');
    register_setting('seo_ai_options_group', 'seo_ai_min_words');
    register_setting('seo_ai_options_group', 'seo_ai_headings_enabled');
    register_setting('seo_ai_options_group', 'seo_ai_meta_enabled');
}
add_action('admin_init', 'seo_ai_register_settings');

// Ayarlar sayfası
function seo_ai_settings_page() {
    ?>
    <div class="wrap">
        <h1>Mimoza AI SEO İçerik Ayarları</h1>
        <form method="post" action="options.php">
            <?php settings_fields('seo_ai_options_group'); ?>
            <label>OpenAI API Anahtarı:</label>
            <input type="text" name="seo_ai_openai_api_key" value="<?php echo esc_attr(get_option('seo_ai_openai_api_key')); ?>" />
            <br>
            <label>Claude AI API Anahtarı:</label>
            <input type="text" name="seo_ai_claude_api_key" value="<?php echo esc_attr(get_option('seo_ai_claude_api_key')); ?>" />
            <br>
            <label>Minimum Kelime Sayısı:</label>
            <input type="number" name="seo_ai_min_words" value="<?php echo esc_attr(get_option('seo_ai_min_words', 500)); ?>" />
            <br>
            <label>Başlıkları Otomatik Ekle:</label>
            <input type="checkbox" name="seo_ai_headings_enabled" value="1" <?php checked(1, get_option('seo_ai_headings_enabled', 1)); ?> />
            <br>
            <label>Meta Açıklaması Ekle:</label>
            <input type="checkbox" name="seo_ai_meta_enabled" value="1" <?php checked(1, get_option('seo_ai_meta_enabled', 1)); ?> />
            <br>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Ana eklenti sayfası
function seo_ai_content_page() {
    ?>
    <div class="wrap">
        <h1>Mimoza AI SEO İçerik Üretici</h1>
        <form method="post" action="">
            <label>Anahtar Kelime:</label>
            <input type="text" name="keyword" required>
            <select name="ai_provider">
                <option value="openai">ChatGPT (OpenAI)</option>
            </select>
            <button type="submit" name="generate">İçerik Üret</button>
        </form>
    </div>
    <?php
    if (isset($_POST['generate'])) {
        seo_ai_generate_content(sanitize_text_field($_POST['keyword']), 'openai');
    }
}

// İçerik oluşturma fonksiyonu
function seo_ai_generate_content($keyword, $ai_provider) {
    $api_keys = [
        'openai' => get_option('seo_ai_openai_api_key')
    ];

    if (empty($api_keys[$ai_provider])) {
        echo '<p style="color: red;">Lütfen API anahtarınızı ayarlar bölümünden giriniz.</p>';
        return;
    }

    $endpoint = 'https://api.openai.com/v1/chat/completions';

    $min_words = get_option('seo_ai_min_words', 500);
    $headings = get_option('seo_ai_headings_enabled', 1) ? 'Başlıkları (H2, H3) ekleyerek oluştur' : '';
    $meta_enabled = get_option('seo_ai_meta_enabled', 1) ? 'Meta açıklaması oluştur' : '';

    $prompt = "SEO uyumlu, tamamlanmış paragraflarla ve tam H2, H3 etiketleriyle bir makale yaz: $keyword. 
    Minimum kelime: $min_words. $headings $meta_enabled.";

    $payload = [
        'model' => 'gpt-4',
        'messages' => [['role' => 'user', 'content' => $prompt]],
        'max_tokens' => 2000
    ];

    $response = wp_remote_post($endpoint, [
        'headers' => [
            'Authorization' => 'Bearer ' . $api_keys[$ai_provider],
            'Content-Type' => 'application/json'
        ],
        'body' => json_encode($payload),
        'timeout' => 60
    ]);

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    if ($data && isset($data['choices'][0]['message']['content'])) {
        $content = $data['choices'][0]['message']['content'];

        $post_data = [
            'post_title'    => $keyword,
            'post_content'  => $content,
            'post_status'   => 'publish',
            'post_author'   => get_current_user_id()
        ];

        $post_id = wp_insert_post($post_data);

        if (!is_wp_error($post_id)) {
            // **Meta Title & Description Ekle**
            update_post_meta($post_id, '_yoast_wpseo_title', "$keyword - " . get_bloginfo('name'));
            update_post_meta($post_id, '_yoast_wpseo_metadesc', substr(strip_tags($content), 0, 150));
            update_post_meta($post_id, 'rank_math_title', "$keyword - " . get_bloginfo('name'));
            update_post_meta($post_id, 'rank_math_description', substr(strip_tags($content), 0, 150));

            echo '<p style="color: green;">✅ İçerik başarıyla oluşturuldu! <a href="' . get_permalink($post_id) . '" target="_blank">Görüntüle</a></p>';
        }
    } else {
        echo '<p style="color: red;">❌ API yanıtı beklenen formatta değil veya boş döndü.</p>';
    }
}




// Kullanıcı Kılavuzu sayfasını ekleyelim
function seo_ai_user_guide_menu() {
    add_submenu_page(
        'seo-ai-content',
        'Kullanıcı Kılavuzu',
        'Kullanıcı Kılavuzu',
        'manage_options',
        'seo-ai-user-guide',
        'seo_ai_user_guide_page'
    );
}
add_action('admin_menu', 'seo_ai_user_guide_menu');

// Kullanıcı Kılavuzu sayfası içeriği
function seo_ai_user_guide_page() {
    echo '<div class="wrap">';
    echo '<h1>Mimoza AI SEO İçerik Eklentisi - Kullanıcı Kılavuzu</h1>';
    echo '<p>Bu eklenti, OpenAI veya Anthropic API ile SEO uyumlu içerikler oluşturmanıza olanak tanır.</p>';
    echo '<p>📖 Detaylı kılavuzu <a href="' . plugin_dir_url(__FILE__) . 'user-guide.pdf" target="_blank">buraya tıklayarak</a> PDF formatında görüntüleyebilirsiniz.</p>';
    echo '<p>🎯 OpenAI API Anahtarı almak için: <a href="https://platform.openai.com/account/api-keys" target="_blank">OpenAI API Key</a></p>';
    echo '<p>🔗 Daha fazla bilgi için: <a href="https://mimozabilisim.com" target="_blank">Mimoza Bilişim</a></p>';
    echo '</div>';
}

?>